use Terminal::ANSI;
use Test;

is parse-input("\x[1B][1;3A"), 'ALT + Up', 'alt up';
is parse-input("\x[1B][1;3D"), 'ALT + Left', 'alt left';
is parse-input("\x[1B][1;5D"), 'CTRL + Left', 'ctrl left';
is parse-input("\x[1B][1;2A"), 'SHIFT + Up', 'shift up';
is parse-input( "\x[1B][1;6C"), 'CTRL + SHIFT + Right', 'ctrl shift right';

done-testing;

