#!raku

use Test;
use Terminal::ANSI;

my @lines;

$*OUT = $*OUT but role { method print($l) { @lines.push($l) } }

clear-screen;
ok @lines[*-1] eq "\e[2J", 'clear-screen';
home;
ok @lines[*-1] eq "\e[H", 'home';

done-testing;
