#!raku

use Test;
use Terminal::ANSI::OO;

my $t = Terminal::ANSI::OO.new;

my @lines;

$*OUT = $*OUT but role { method print($l) { @lines.push($l) } }

$t.clear-screen;
ok @lines[*-1] eq "\e[2J", 'clear-screen';

$t.home;
ok @lines[*-1] eq "\e[H", 'home';

done-testing;

